@@ -1,5 +1,5 @@
 gmci.default <-
-  function (gm, alpha, eps = 1e-04, cimethod= "SdR", expmethod = "PadeRBS", ...) 
+  function (gm, alpha, eps = 1e-04, cimethod= "Direct", expmethod = "PadeRBS", ...) 
   {
     if (gm$method == "Expectation-Maximization Algorithm") {
       if(cimethod=="SdR"){
@@ -8,6 +8,12 @@ gmci.default <-
       if(cimethod=="BS"){
         limits = ciEMBS(gm, alpha, eps, expmethod)
       }
+      if(cimethod=="Direct"){
+        limits = ciEMoFI(gm, alpha, eps, expmethod)
+      }
+      if(cimethod=="DM"){
+        limits = ciEMDM(gm, alpha, eps, expmethod)
+      }
       limits$method = "Wald Confidence Interval (Oakes Standard Error)"
     }
     if (gm$method == "Gibbs Sampler") {
